@@ -1,27 +1,26 @@
 # Builtin modules
 from __future__ import annotations
 from fnmatch import fnmatchcase
-from typing import Dict, List, Any, Union, Optional, cast
+from typing import List, Any, Union, Optional, cast
 from collections import OrderedDict
 # Third party modules
 # Local modules
+from .abcs import T_Filter
 from .globHandler import _GlobHandler
 from .levels import Levels
 # Program
-class Filter:
-	keys:Dict[str, Filter]
-	fallbackLevel:int
+class Filter(T_Filter):
 	__slots__ = ("keys", "fallbackLevel")
 	def __init__(self, fallbackLevel:int) -> None:
-		self.keys          = cast(Dict[str, Filter], OrderedDict())
+		self.keys          = OrderedDict()
 		self.fallbackLevel = fallbackLevel
-	def addLogger(self, k:str, v:Filter) -> Filter:
+	def addLogger(self, k:str, v:T_Filter) -> T_Filter:
 		self.keys[k] = v
 		return self
 	def setFallbackLevel(self, level:Union[int, str]) -> None:
 		self.fallbackLevel = Levels.parse(level)
 		return None
-	def getKey(self, k:str) -> Optional[Filter]:
+	def getKey(self, k:str) -> Optional[T_Filter]:
 		return self.keys[k.lower()] if k.lower() in self.keys else None
 	def getFilteredID(self, path:List[str]) -> int:
 		name = path.pop(0)
@@ -37,7 +36,7 @@ class Filter:
 		for key, val in self.keys.items():
 			ret.append({ key:val.dump() })
 		return ret
-	def extend(self, inp:Filter) -> None:
+	def extend(self, inp:T_Filter) -> None:
 		if inp.fallbackLevel != 0:
 			self.fallbackLevel = inp.fallbackLevel
 		for key, val in inp.keys.items():
@@ -51,7 +50,7 @@ class Filter:
 
 class FilterParser:
 	@staticmethod
-	def fromString(data:str) -> Filter:
+	def fromString(data:str) -> T_Filter:
 		"""
 		parent:ERROR,parent.children.son:WARNING
 		->
@@ -68,7 +67,7 @@ class FilterParser:
 			]}
 		]
 		"""
-		lastScope:Filter
+		lastScope:T_Filter
 		ret = Filter(0)
 		for part in data.lower().split(","):
 			rawPaths, levelID = part.split(":")
@@ -80,7 +79,7 @@ class FilterParser:
 				lastScope = lastScope.keys[path]
 		return ret
 	@classmethod
-	def fromJson(cls, datas:List[Any]) -> Filter:
+	def fromJson(cls, datas:List[Any]) -> T_Filter:
 		"""
 		[
 			{ "parent": [
